"use strict";

{
  C3.Plugins.StraniAnelli_InjectCSS.Instance = class StraniAnelli_InjectCSSInstance extends C3.SDKInstanceBase {
    constructor(inst, properties) {
      super(inst);

      this.elencoProprieta = {
        CSSFiles: 0,      // elenco dei file css inseriti nel progetto
        CSSExternal: 1,   // elenco dei file da importare da risorse esterne
        JSFiles: 2,
        JSExternal: 3
      };

      // imposto i valori predefiniti
      this.CSSFiles = '';
      this.CSSExternal = '';
      this.JSFiles = '';
      this.JSExternal = '';

      // assegno i valori
      if (properties) {
        this.CSSFiles = properties[this.elencoProprieta.CSSFiles];
        this.CSSExternal = properties[this.elencoProprieta.CSSExternal];
        this.JSFiles = properties[this.elencoProprieta.JSFiles];
        this.JSExternal = properties[this.elencoProprieta.JSExternal];
      }

      if (this.CSSExternal != '') {
        // i nomi dei file CSS sono ognuno su una riga diversa
        // inserisco ogni riga in un array
        let righe = [];
        righe = this.CSSExternal.split('\n');

        for (let i = 0; i < righe.length; i++) {
          // salta la riga se contiene solo spazi oppure se è vuota
          let temp = righe[i];
          if (!temp.replace(/\s/g, '').length) continue;

          const nameCSS = this.GetProjectFileUrl(righe[i], false);
          this.InjectCSSIntoHead(nameCSS);
        }
      }

      if (this.CSSFiles != '') {
        let righe = [];
        righe = this.CSSFiles.split('\n');

        for (let i = 0; i < righe.length; i++) {
          let temp = righe[i];
          if (!temp.replace(/\s/g, '').length) continue;

          const nameCSS = this.GetProjectFileUrl(righe[i], true);
          this.InjectCSSIntoHead(nameCSS);
        }
      }

      if (this.JSExternal != '') {
        let righe = [];
        righe = this.JSExternal.split('\n');

        for (let i = 0; i < righe.length; i++) {
          let temp = righe[i];
          if (!temp.replace(/\s/g, '').length) continue;

          const nameJS = this.GetProjectFileUrl(righe[i], false);
          this.InjectJSIntoHead(nameJS);
        }
      }

      if (this.JSFiles != '') {
        let righe = [];
        righe = this.JSFiles.split('\n');

        for (let i = 0; i < righe.length; i++) {
          let temp = righe[i];
          if (!temp.replace(/\s/g, '').length) continue;

          const nameJS = this.GetProjectFileUrl(righe[i], true);
          this.InjectJSIntoHead(nameJS);
        }
      }

    }

    Release() { super.Release(); }

    SaveToJson() { return {}; }

    LoadFromJson(o) {}
  };


  // per inserire funzioni generali utili
  var InstanceFunctionsObject = {
    // in c3 i file locali hanno un indirizzo diverso quando sono nell'anteprima
    GetProjectFileUrl(nameFile, isLocal) {
      let nameInProject = nameFile;
      if ( isLocal && this._runtime.IsPreview() ) {
        nameInProject = this._runtime.GetAssetManager().GetProjectFileUrl(nameFile);
      }
      return nameInProject;
    },

    // ----- CSS ----- //
        // inserisci il file CSS nell'head
        InjectCSSIntoHead(nameCSS) {
          let element = document.createElement("link");
          element.setAttribute("rel", "stylesheet");
          element.setAttribute("type", "text/css");
          element.setAttribute("href", nameCSS);
          element.setAttribute("createdbystranianelliinjectcss","");
          document.head.appendChild(element);
        },
        RemoveCSSFromPage(arrayCSS, nameCSS) {
          for (let i = 0; i < arrayCSS.length; i++) {
            if (arrayCSS[i].href.substr(-nameCSS.length) == nameCSS) {
              arrayCSS[i].parentNode.removeChild(arrayCSS[i]);
              i--;
            }
          }
        },
        RemoveAllImportedCSSFromPage() {
          const links = document.head.getElementsByTagName("link");
          for (let i = 0; i < links.length; i++) {
            if (links[i].hasAttribute("createdbystranianelliinjectcss")) {
              links[i].parentNode.removeChild(links[i]);
              i--;
            }
          }
        },
        RemoveAllCSSFromPage() {
          const links = document.head.getElementsByTagName("link");
          for (let i = 0; i < links.length; i++) {
            if (links[i].rel="stylesheet") {
              links[i].parentNode.removeChild(links[i]);
              i--;
            }
          }
        },
        EnableCSS(arrayCSS, nameCSS, isEnabled) {
          for (let i = 0; i < arrayCSS.length; i++) {
            if (arrayCSS[i].href.substr(-nameCSS.length) == nameCSS) {
              arrayCSS[i].disabled = !isEnabled;
            }
          }
        },

    // ----- JS ----- //
        // inserisci il file JS nell'head
        InjectJSIntoHead(nameJS) {
          let element = document.createElement("script");
          element.setAttribute("type", "text/javascript");
          element.setAttribute("src", nameJS);
          element.setAttribute("createdbystranianelliinjectcss","");
          document.head.appendChild(element);
        },
        RemoveJSFromPage(arrayJS, nameJS) {
          for (let i = 0; i < arrayJS.length; i++) {
            if (arrayJS[i].src.substr(-nameJS.length) == nameJS) {
              arrayJS[i].parentNode.removeChild(arrayJS[i]);
              i--;
            }
          }
        },
        RemoveAllImportedJSFromPage() {
          const scripts = document.head.getElementsByTagName("script");
          for (let i = 0; i < scripts.length; i++) {
            if (scripts[i].hasAttribute("createdbystranianelliinjectcss")) {
              scripts[i].parentNode.removeChild(scripts[i]);
              i--;
            }
          }
        },

    // ----- CANVAS ----- //
        DestroyCanvasFromPage() {
          // aggiungi controllo se esiste
          const canvas = document.body.getElementsByTagName("canvas");
          canvas[0].parentNode.removeChild(canvas[0]);
        },

    // ----- HTML ----- //
        CreateHTMLElement(newElement) {
          let fragment =  document.createDocumentFragment();
          let temp = document.createElement("div");
          temp.innerHTML = newElement;
          while (temp.firstChild) {
            fragment.appendChild(temp.firstChild);
          }
          return fragment;
        },

        DestroyHTMLElementByID(idElement) {
          const element = document.getElementById(idElement);
          element.parentNode.removeChild(element);
        }

  }

  for( var k in InstanceFunctionsObject )
  {
    C3.Plugins.StraniAnelli_InjectCSS.Instance.prototype[k] = InstanceFunctionsObject[k];
  }

}
